@@ -25,7 +25,7 @@ copyright = "{}, Django Debug Toolbar developers and contributors"
 copyright = copyright.format(datetime.date.today().year)
 
 # The full version, including alpha/beta/rc tags
-release = "3.8.1"
+release = "4.1.0"
 
 
 # -- General configuration ---------------------------------------------------
@@ -59,8 +59,11 @@ html_theme = "default"
 # html_static_path = ['_static']
 
 intersphinx_mapping = {
-    "https://docs.python.org/": None,
-    "https://docs.djangoproject.com/en/dev/": "https://docs.djangoproject.com/en/dev/_objects/",
+    "python": ("https://docs.python.org/", None),
+    "django": (
+        "https://docs.djangoproject.com/en/dev/",
+        "https://docs.djangoproject.com/en/dev/_objects/",
+    ),
 }
 
 # -- Options for Read the Docs -----------------------------------------------
