@@ -14,7 +14,11 @@ from django.shortcuts import render
 from django.test.utils import override_settings
 
 import debug_toolbar.panels.sql.tracking as sql_tracking
-from debug_toolbar import settings as dt_settings
+
+try:
+    import psycopg
+except ImportError:
+    psycopg = None
 
 from ..base import BaseMultiDBTestCase, BaseTestCase
 from ..models import PostgresJSON
@@ -221,6 +225,30 @@ class SQLPanelTestCase(BaseTestCase):
             '["{\\"foo\\": \\"bar\\"}"]',
         )
 
+    @unittest.skipUnless(
+        connection.vendor == "postgresql" and psycopg is None,
+        "Test valid only on PostgreSQL with psycopg2",
+    )
+    def test_tuple_param_conversion(self):
+        """
+        Regression test for tuple parameter conversion.
+        """
+        self.assertEqual(len(self.panel._queries), 0)
+
+        list(
+            PostgresJSON.objects.raw(
+                "SELECT * FROM tests_postgresjson WHERE field ->> 'key' IN %s",
+                [("a", "b'")],
+            )
+        )
+
+        response = self.panel.process_request(self.request)
+        self.panel.generate_stats(self.request, response)
+
+        # ensure query was logged
+        self.assertEqual(len(self.panel._queries), 1)
+        self.assertEqual(self.panel._queries[0]["params"], '[["a", "b\'"]]')
+
     def test_binary_param_force_text(self):
         self.assertEqual(len(self.panel._queries), 0)
 
@@ -357,12 +385,15 @@ class SQLPanelTestCase(BaseTestCase):
     @unittest.skipUnless(
         connection.vendor == "postgresql", "Test valid only on PostgreSQL"
     )
-    def test_execute_with_psycopg2_composed_sql(self):
+    def test_execute_with_psycopg_composed_sql(self):
         """
-        Test command executed using a Composed psycopg2 object is logged.
-        Ref: http://initd.org/psycopg/docs/sql.html
+        Test command executed using a Composed psycopg object is logged.
+        Ref: https://www.psycopg.org/psycopg3/docs/api/sql.html
         """
-        from psycopg2 import sql
+        try:
+            from psycopg import sql
+        except ImportError:
+            from psycopg2 import sql
 
         self.assertEqual(len(self.panel._queries), 0)
 
@@ -426,42 +457,92 @@ class SQLPanelTestCase(BaseTestCase):
         # ensure the stacktrace is populated
         self.assertTrue(len(query["stacktrace"]) > 0)
 
-    @override_settings(
-        DEBUG_TOOLBAR_CONFIG={"PRETTIFY_SQL": True},
-    )
     def test_prettify_sql(self):
         """
         Test case to validate that the PRETTIFY_SQL setting changes the output
         of the sql when it's toggled. It does not validate what it does
         though.
         """
-        list(User.objects.filter(username__istartswith="spam"))
-
-        response = self.panel.process_request(self.request)
-        self.panel.generate_stats(self.request, response)
-        pretty_sql = self.panel._queries[-1]["sql"]
-        self.assertEqual(len(self.panel._queries), 1)
+        with override_settings(DEBUG_TOOLBAR_CONFIG={"PRETTIFY_SQL": True}):
+            list(User.objects.filter(username__istartswith="spam"))
+            response = self.panel.process_request(self.request)
+            self.panel.generate_stats(self.request, response)
+            pretty_sql = self.panel._queries[-1]["sql"]
+            self.assertEqual(len(self.panel._queries), 1)
 
         # Reset the queries
         self.panel._queries = []
         # Run it again, but with prettify off. Verify that it's different.
-        dt_settings.get_config()["PRETTIFY_SQL"] = False
-        list(User.objects.filter(username__istartswith="spam"))
-        response = self.panel.process_request(self.request)
-        self.panel.generate_stats(self.request, response)
-        self.assertEqual(len(self.panel._queries), 1)
-        self.assertNotEqual(pretty_sql, self.panel._queries[-1]["sql"])
+        with override_settings(DEBUG_TOOLBAR_CONFIG={"PRETTIFY_SQL": False}):
+            list(User.objects.filter(username__istartswith="spam"))
+            response = self.panel.process_request(self.request)
+            self.panel.generate_stats(self.request, response)
+            self.assertEqual(len(self.panel._queries), 1)
+            self.assertNotEqual(pretty_sql, self.panel._queries[-1]["sql"])
 
         self.panel._queries = []
         # Run it again, but with prettify back on.
         # This is so we don't have to check what PRETTIFY_SQL does exactly,
         # but we know it's doing something.
-        dt_settings.get_config()["PRETTIFY_SQL"] = True
-        list(User.objects.filter(username__istartswith="spam"))
+        with override_settings(DEBUG_TOOLBAR_CONFIG={"PRETTIFY_SQL": True}):
+            list(User.objects.filter(username__istartswith="spam"))
+            response = self.panel.process_request(self.request)
+            self.panel.generate_stats(self.request, response)
+            self.assertEqual(len(self.panel._queries), 1)
+            self.assertEqual(pretty_sql, self.panel._queries[-1]["sql"])
+
+    def test_simplification(self):
+        """
+        Test case to validate that select lists for .count() and .exist() queries do not
+        get elided, but other select lists do.
+        """
+        User.objects.count()
+        User.objects.exists()
+        list(User.objects.values_list("id"))
         response = self.panel.process_request(self.request)
         self.panel.generate_stats(self.request, response)
-        self.assertEqual(len(self.panel._queries), 1)
-        self.assertEqual(pretty_sql, self.panel._queries[-1]["sql"])
+        self.assertEqual(len(self.panel._queries), 3)
+        self.assertNotIn("\u2022", self.panel._queries[0]["sql"])
+        self.assertNotIn("\u2022", self.panel._queries[1]["sql"])
+        self.assertIn("\u2022", self.panel._queries[2]["sql"])
+
+    def test_top_level_simplification(self):
+        """
+        Test case to validate that top-level select lists get elided, but other select
+        lists for subselects do not.
+        """
+        list(User.objects.filter(id__in=User.objects.filter(is_staff=True)))
+        list(User.objects.filter(id__lt=20).union(User.objects.filter(id__gt=10)))
+        if connection.vendor != "mysql":
+            list(
+                User.objects.filter(id__lt=20).intersection(
+                    User.objects.filter(id__gt=10)
+                )
+            )
+            list(
+                User.objects.filter(id__lt=20).difference(
+                    User.objects.filter(id__gt=10)
+                )
+            )
+        response = self.panel.process_request(self.request)
+        self.panel.generate_stats(self.request, response)
+        if connection.vendor != "mysql":
+            self.assertEqual(len(self.panel._queries), 4)
+        else:
+            self.assertEqual(len(self.panel._queries), 2)
+        # WHERE ... IN SELECT ... queries should have only one elided select list
+        self.assertEqual(self.panel._queries[0]["sql"].count("SELECT"), 4)
+        self.assertEqual(self.panel._queries[0]["sql"].count("\u2022"), 3)
+        # UNION queries should have two elidid select lists
+        self.assertEqual(self.panel._queries[1]["sql"].count("SELECT"), 4)
+        self.assertEqual(self.panel._queries[1]["sql"].count("\u2022"), 6)
+        if connection.vendor != "mysql":
+            # INTERSECT queries should have two elidid select lists
+            self.assertEqual(self.panel._queries[2]["sql"].count("SELECT"), 4)
+            self.assertEqual(self.panel._queries[2]["sql"].count("\u2022"), 6)
+            # EXCEPT queries should have two elidid select lists
+            self.assertEqual(self.panel._queries[3]["sql"].count("SELECT"), 4)
+            self.assertEqual(self.panel._queries[3]["sql"].count("\u2022"), 6)
 
     @override_settings(
         DEBUG=True,
