@@ -65,6 +65,35 @@ class DebugToolbarTestCase(BaseTestCase):
         with self.settings(INTERNAL_IPS=[]):
             self.assertFalse(show_toolbar(self.request))
 
+    def test_should_render_panels_RENDER_PANELS(self):
+        """
+        The toolbar should force rendering panels on each request
+        based on the RENDER_PANELS setting.
+        """
+        toolbar = DebugToolbar(self.request, self.get_response)
+        self.assertFalse(toolbar.should_render_panels())
+        toolbar.config["RENDER_PANELS"] = True
+        self.assertTrue(toolbar.should_render_panels())
+        toolbar.config["RENDER_PANELS"] = None
+        self.assertTrue(toolbar.should_render_panels())
+
+    def test_should_render_panels_multiprocess(self):
+        """
+        The toolbar should render the panels on each request when wsgi.multiprocess
+        is True or missing.
+        """
+        request = rf.get("/")
+        request.META["wsgi.multiprocess"] = True
+        toolbar = DebugToolbar(request, self.get_response)
+        toolbar.config["RENDER_PANELS"] = None
+        self.assertTrue(toolbar.should_render_panels())
+
+        request.META["wsgi.multiprocess"] = False
+        self.assertFalse(toolbar.should_render_panels())
+
+        request.META.pop("wsgi.multiprocess")
+        self.assertTrue(toolbar.should_render_panels())
+
     def _resolve_stats(self, path):
         # takes stats from Request panel
         self.request.path = path
@@ -671,8 +700,51 @@ class DebugToolbarLiveTestCase(StaticLiveServerTestCase):
         hide_button = self.selenium.find_element(By.ID, "djHideToolBarButton")
         assert hide_button.text == "Hide »"
 
+        self.get("/execute_sql/")
+        sql_panel = self.selenium.find_element(By.ID, "SQLPanel")
+
+        # Click to show the SQL panel
+        self.selenium.find_element(By.CLASS_NAME, "SQLPanel").click()
+
+        table = self.wait.until(
+            lambda selenium: sql_panel.find_element(By.TAG_NAME, "table")
+        )
+        self.assertIn("Query", table.text)
+        self.assertIn("Action", table.text)
+
     @override_settings(DEBUG_TOOLBAR_CONFIG={"TOOLBAR_LANGUAGE": "pt-br"})
     def test_toolbar_language_will_render_to_locale_when_set(self):
         self.get("/regular/basic/")
         hide_button = self.selenium.find_element(By.ID, "djHideToolBarButton")
         assert hide_button.text == "Esconder »"
+
+        self.get("/execute_sql/")
+        sql_panel = self.selenium.find_element(By.ID, "SQLPanel")
+
+        # Click to show the SQL panel
+        self.selenium.find_element(By.CLASS_NAME, "SQLPanel").click()
+
+        table = self.wait.until(
+            lambda selenium: sql_panel.find_element(By.TAG_NAME, "table")
+        )
+        self.assertIn("Query", table.text)
+        self.assertIn("Linha", table.text)
+
+    @override_settings(DEBUG_TOOLBAR_CONFIG={"TOOLBAR_LANGUAGE": "en-us"})
+    @override_settings(LANGUAGE_CODE="de")
+    def test_toolbar_language_will_render_to_locale_when_set_both(self):
+        self.get("/regular/basic/")
+        hide_button = self.selenium.find_element(By.ID, "djHideToolBarButton")
+        assert hide_button.text == "Hide »"
+
+        self.get("/execute_sql/")
+        sql_panel = self.selenium.find_element(By.ID, "SQLPanel")
+
+        # Click to show the SQL panel
+        self.selenium.find_element(By.CLASS_NAME, "SQLPanel").click()
+
+        table = self.wait.until(
+            lambda selenium: sql_panel.find_element(By.TAG_NAME, "table")
+        )
+        self.assertIn("Query", table.text)
+        self.assertIn("Action", table.text)
